#include <iostream>
#include <vector>
#include <string>

using namespace std;

const auto IMAGE_WIDTH = 400;
const auto IMAGE_HEIGHT = 300;
const auto TEXT_LEFT = 20;
const auto TEXT_BASELINE = 20;
const auto TEXT_WIDTH = 50;
const auto BIN_HEIGHT = 30;
const auto BLOCK_WIDTH = 10;

void
svg_begin(double width, double height) {
    cout << "<?xml version='1.0' encoding='UTF-8'?>\n";
    cout << "<svg ";
    cout << "width='" << width << "' ";
    cout << "height='" << height << "' ";
    cout << "viewBox='0 0 " << width << " " << height + 100 << "' ";
    cout << "xmlns='http://www.w3.org/2000/svg'>\n";
}

void
svg_end() {
    cout << "</svg>\n";
}

void
svg_text(double left, double baseline, string text) {
    cout << "<text x='" << left << "' y='" << baseline << "' >" << text << "</text> \n";
}

void
svg_rect(double x, double y, double width, double height) {
    cout << "<rect x='" << x << "' y='" << y << "' width='" << width << "' height='" << height << "' stroke='#6600CC' fill='#aaffaa' /> \n";
}


void
show_histogram_svg(const vector<size_t>& bins) {
    double top = 0.0;
    double move = 0.0;
    svg_begin(IMAGE_WIDTH, IMAGE_HEIGHT);
    double k = 1.0;
    size_t max_bin = bins[0];
    for (size_t bin : bins) {
        if (bin > max_bin) {
            max_bin = bin;
        }
    }
    if (max_bin * 10 > IMAGE_HEIGHT) {
        k = double(IMAGE_HEIGHT - 10) / (max_bin * 10);
    }
    for (size_t bin : bins) {
        svg_text(TEXT_LEFT + move, TEXT_BASELINE, to_string(bin));
        move += BIN_HEIGHT;
    }
    top += 3 * BLOCK_WIDTH;
    move = 13.0;
    for (size_t bin : bins) {

        const double bin_width = BLOCK_WIDTH * bin * k;
        svg_rect(move, top, BIN_HEIGHT, bin_width);
        move += BIN_HEIGHT;
    }
    svg_end();
}